/**
 * A loadable configuration is able to fetch a piece of configuration from a location.
 */
export interface LoadableConfiguration<TLoaderOptions> {
    load(options: TLoaderOptions): Promise<string>;
}
/**
 * An already parsed loadable configuration is able to fetch an already parsed piece of configuration.
 */
export interface ParsedLoadableConfiguration<TConfiguration, TLoaderOptions> {
    load(options: TLoaderOptions): Promise<TConfiguration>;
}
/**
 * Thrown when something went wrong while loading a configuration.
 */
export declare class ConfigurationLoadingError extends Error {
    readonly loaderName: string;
    readonly innerError: unknown | undefined;
    constructor(message: string, loaderName: string, innerError?: unknown);
    hasInnerError(): boolean;
}
export declare const isConfigurationLoadingError: (something: any) => something is ConfigurationLoadingError;
//# sourceMappingURL=LoadableConfiguration.d.ts.map